VertexArray
===========

.. py:module:: moderngl
.. py:currentmodule:: moderngl

.. literalinclude:: first.3.py
    :emphasize-lines: 2,33-
    :linenos:

Proceed to the :doc:`next step <rendering>`.
